function find_open_close_cb(arg1,arg2)
%Automatically find all open/close events in f-ext (for all traces) and add
%to the list of events. This should only be run before doing any manual
%open/close annotation or will get double counts. You can use the manual
%addition and deletion after runing this code in order to correct these
%results.

%140407 mjc

%Should subtract a smooth curve from the entire trace to get rid of the base
%polymer slope. Thought about using the model curve, but the dna only model doesn't
%match well for the peptide at high force (with open peptide). But for our
%derivative purpose, just need anything that smoothly fits. A 6th order polymer does
%a very nice job.

%delete previously found events first
delete_all_cb;

%These parameters can be set from the command window as globals. Should set
%them this way (don't change the defaults). If not, use defaults.

global ds_factor
if isempty(ds_factor)
    ds_factor = 4;%factor to use to downsample data
end

global avewindow
if isempty(avewindow)
    avewindow = 3;%averging for step finding
end

global smthx
if isempty(smthx)
    smthx = 0;%smoothing for derivative for step finding, 0 means no smoothing
end

global F_thresh
if isempty(F_thresh)
    F_thresh = 0.3;%derivative threshold for a force step (pN)
end

global ext_thresh
if isempty(ext_thresh)
    ext_thresh = 3;%derivative threshold for an extension step (nm)
end

global f_ext_diag
if isempty(f_ext_diag)
    f_ext_diag = 0;%plot diagnostics if true
end

%it doesn't actually matter what this is set to
databw = 533;%data sampling rate (Hz)

hfig = gcf;
ud = get(gcf,'userd');

xy = [];

% Locate line objects
hlines = findall(gca,'Type','line');
hlines = flipud(hlines);%flip upside down to get in proper order
hfit = hlines(ud.ntraces+1);%the handle of the fit
hlines = hlines(1:ud.ntraces);%want first n traces (next is model, then markers)

F_fit = get(hfit,'ydata');
ext_fit = get(hfit,'xdata');

if f_ext_diag
    hdebugfig = figure('pos',[474         350        1775         823]);
    colors = lines(ud.ntraces);%line colors for plotting
    global offset_curves
    if isempty(offset_curves)
        offset_curves = F_thresh*4;%offset individual curves to see in plots, pN
        offset_curves = 1;
    end
end

for l = 1:ud.ntraces
% for l = 1
    htrace = hlines(l);
    tag = get(htrace,'tag');
    F = get(htrace,'ydata');
    ext = get(htrace,'xdata');
    
    t = (1:length(F))*1/databw;
    
    %fit a polymer to subtract the base f-ext
    pF = polyfit(t,F,6);%6th order is working very well for the peptide construct
    F_pfit = polyval(pF,t);
    F_offsub = F - F_pfit;
    
    pExt = polyfit(t,ext,6);%6th order is working very well for the peptide construct
    ext_pfit = polyval(pExt,t);
    ext_offsub = ext - ext_pfit;
    
    F_ds = downsample(F,ds_factor);
    ext_ds = downsample(ext,ds_factor);
    F_offsub_ds = downsample(F_offsub,ds_factor);
    ext_offsub_ds = downsample(ext_offsub,ds_factor);
    
    t_ds = downsample(t,ds_factor);
    
    if f_ext_diag 
        %just need to look and force, ext is redundant
        figure(hdebugfig)
        subplot(1,2,1)
%         plot(t,F,'k')
        hold on
        offset = (l-1)*offset_curves;
        plot(t_ds,F_ds+offset,'Color',colors(l,:))
        plot(t,F_pfit+offset,'k:')
        ylabel('Force (pN)')
        xlabel('Time (s)')
        title('Downsampled f-ext with polymer fits')
%         subplot(2,2,2)
% %         plot(t,ext,'k')
%         hold on
%         plot(t_ds,ext_ds+(l-1)*100,'Color',colors(l,:))
%         plot(t,ext_pfit,'k:')
    end
    
    %find opening/closing steps in data using my findsteps routine (used
    %for oligo fluorescence analysis previously)
    [F_deriv F_events1 F_events2] = findsteps(F_offsub_ds,avewindow,smthx,F_thresh);
    [ext_deriv ext_events1 ext_events2] = findsteps(ext_offsub_ds,avewindow,smthx,ext_thresh);
    
    F_events = F_events1 + F_events2;%combine open and closed events (separate in analysis phase)
    ext_events = ext_events1 + ext_events2;
    
    iF_events = find(F_events == 1);%indices of events
    iext_events = find(ext_events == 1);
    
    nevents = length(iF_events);
    for i = 1:nevents
        ievent = iF_events(i);
        
        if mod(l,2) %choose order of points (order should occur in time)
            %odd, a pull
            x1 = ext_ds(ievent-2);
            y1 = F_ds(ievent-2);
            x2 = ext_ds(ievent+2);
            y2 = F_ds(ievent+2);
        else
            %even, a relaxation
            x1 = ext_ds(ievent+2);
            y1 = F_ds(ievent+2);
            x2 = ext_ds(ievent-2);
            y2 = F_ds(ievent-2);
        end
        
        figure(hfig)
        h1 = plot(x1,y1,'gx','linew',2,'markersize',10,'tag',tag);
        h2 = plot(x2,y2,'rx','linew',2,'markersize',10,'tag',tag);
        xy = [xy;[x1 y1 h1 x2 y2 h2 l]];
        
    end
    
    if f_ext_diag
        figure(hdebugfig)
        %just plot force, ignore ext
        subplot(1,2,2)
        offset = l*offset_curves;
        plot(t_ds(5:end-5),F_deriv(5:end-5)+offset,'Color',colors(l,:)) %ends of derivative are screwy
        hold on
        %threshold
        plot([t_ds(5) t_ds(end-5)],[1 1]*(-F_thresh+offset),'k:')
        plot([t_ds(5) t_ds(end-5)],[1 1]*(F_thresh+offset),'k:')
     
        xlabel('Time (s)')
        title('F-ext with fits subtracted and thresholds for peak finding shown')
        
%         subplot(2,2,4)
%         plot(t_ds(5:end-5),ext_deriv(5:end-5)+(l-1)*5,'Color',colors(l,:)) %ends of derivative are screwy
%         hold on
        
%         sum(F_events)
%         sum(ext_events)
    end
    
end

ud.fext_pairs = xy;

set(hfig,'userd',ud);
